@@ -118,7 +118,7 @@ class LinuxDevice(object):
     '''
     A base class for common linux devices.
     '''
-    version = '1.1.17'
+    release = '1.1.18'
 
     LOG_EMERG = 0   # not used
     LOG_ALERT = 1   # not used
@@ -207,10 +207,12 @@ class LinuxDevice(object):
             #self.del__configure_interface()
             self._preconfig()
 
+        self["netdevice"] = self.release
         if self["type"] == 'Linux':
             tmp = copy.deepcopy(self.attributes)
             tmp["password"] = "*******"
             self.log("%s = %s\n" %(self.name, json.dumps(tmp, indent=4)))
+
         #self.x_get_interface()
         #self.log("interface = %s\n" %(json.dumps(self.interface, indent=4)))
 
@@ -222,9 +224,8 @@ class LinuxDevice(object):
         if self['postconfig']:
             for c in self['postconfig']:
                 self.cmd(c)
-        self.log("%s.%s(%s), finish in %.2f seconds\n" %(self.__class__.__name__,
+        self.log("%s.%s, finish in %.2f seconds\n" %(self.__class__.__name__,
             sys._getframe().f_code.co_name,
-            self.version,
             time.time() - self.start_time))
         #self.cmd('rm $INPUTRC', log_level = self.LOG_WARNING)
         #self.psession.close(force=True)
